@@ -4,6 +4,7 @@ import functools
 def set_run(func):
     @functools.wraps(func)
     def wrapper(self, *args, **kwargs):
-        func(self, *args, **kwargs)
+        value = func(self, *args, **kwargs)
         self.is_run = True
+        return value
     return wrapper
\ No newline at end of file
